# Importing the modules
from file_modification import clear_files, returnGradeTables
from login import login, getTime
from grades import initializeClasses, returnGrades
from notification import isUpdated
from test import userInput

# Initalization
print("--------------------------------------------\n\tWelcome to the HAC API!\n--------------------------------------------")
print("    https://github.com/Nazchanel")
print()
print("\t  Version: 1.0.0")
print("\t Date: 4/01/2023")
